@@ -212,8 +212,6 @@ class RKXMLRequest(XMLRequest):
 
         body = '<RK7Query><RK7CMD CMD="GetOrderList"/></RK7Query>'
         response = self.send_request(body=body)
-        with open('order_list.txt', 'w') as file:
-            file.write(response.text)
         element_list = []
         try:
             parsed_element = Etree.fromstring(response.content)
@@ -282,8 +280,6 @@ class RKXMLRequest(XMLRequest):
 
         body = '<RK7Query><RK7CMD CMD="GetRefData" RefName = "MENUITEMS"/></RK7Query>'
         response = self.send_request(body=body)
-        files = open('dish.txt', 'w')
-        files.write(response.text)
         element = []
         try:
             parsed_element = Etree.fromstring(response.content)
@@ -362,8 +358,6 @@ class RKXMLRequest(XMLRequest):
             'WithMacroProp="1" OnlyActive = "1"/></RK7Query>'
         element = []
         response = self.send_request(body=body)
-        files = open('category.txt', 'w')
-        files.write(response.text)
         try:
             parsed_element = Etree.fromstring(response.content)
             for item in parsed_element.findall("./RK7Reference/Items/"):
@@ -396,8 +390,6 @@ class RKXMLRequest(XMLRequest):
         for guid in self.get_visits():
             body = f'<RK7Query><RK7Command CMD="GetOrder"><Order guid="{guid}"/></RK7Command></RK7Query>'
             response = self.send_request(body=body)
-            files = open('test.txt', 'w')
-            files.write(response.text)
             parsed_collection = Etree.fromstring(response.content)
             for order in parsed_collection.findall('./CommandResult/Order'):
                 order_item = order.attrib
